@@ -12,13 +12,14 @@
 logfile="/var/log/userful-start.log"
 
 # create backup for log files
-for F in "1box-server.log" "usbinput.log" "userful-start.log"; do
-	# make backup
-	mv --backup=numbered /var/log/$F /var/log/$F.old
+for F in "1box-server.log" "usbinput.log" "userful-start.log" "userful-multiuser-device.log" "login-server.log"; do
+
+	if [ -f /var/log/$F ]; then
+		# make backup
+		mv --backup=numbered /var/log/$F /var/log/$F.old 2>> $logfile
+	fi
 
 	# delete backup files older than 30 days
 	find /var/log/ -name "$F.old*" -mtime +30 -exec rm -f \{\} \;
 done
 
-date >> $logfile
-echo >> $logfile
