@@ -36,3 +36,6 @@ elif grep "^#TerminateServer=" $CONFIG_FILE > /dev/null 2>&1; then
 else
     sed -i -e "s/^\[X-:\*-Core\]/\[X-:\*-Core\]\nTerminateServer=true/g" $CONFIG_FILE
 fi
+
+# Disable AutoLogin
+sed -i -e "s/^AutoLoginEnable=true/AutoLoginEnable=flase/g" $CONFIG_FILE
