@@ -92,6 +92,7 @@ check_laptop()
 				   awk -- '{if(substr($3,2,4) == "Card") {split($0,a,"\""); print a[2]}}' |
 				   awk -- '{split($0,b,":"); print b[2]}'`
 
+        # Graphics card for laptop has following strings in it's product name.
 		if echo $CARDNAME | tr "[A-Z]" "[a-z]" | grep " mobility" > /dev/null 2>&1 || \
 		   echo $CARDNAME | tr "[A-Z]" "[a-z]" | grep " igp" > /dev/null 2>&1 || \
 		   echo $CARDNAME | tr "[A-Z]" "[a-z]" | grep " go" > /dev/null 2>&1 ; then
@@ -102,9 +103,9 @@ check_laptop()
 }
 
 ###
-# check if there is touchscreen device in the system
-# It assumes that any device that has ELOTOUCH and MITOUCH for the Vendor ID 
-# is a Touch screen device
+# - Check if there is touchscreen device in the system
+# - Assumes that any device that has ELOTOUCH and MITOUCH for the Vendor ID 
+#   is a Touch screen device
 ###
 function check_touchscreen()
 {
@@ -199,28 +200,37 @@ function configure_mx()
 	echo "`date +"%b %d %T"` $ProgramName: Run \"X -configure\" to create $XORG_CONF_NEW " >> $logfile
 	rm -f /root/$XORG_CONF_NEW /$XORG_CONF_NEW  2> /dev/null
 
-	# If system has savage colorgraphics card, don't start X -configure
-	# because X has problem with multiple savage colorgraphics cards (5333:8A22)
+	# If system has savage colorgraphics card, don't run "X -configure"
+	# because X has problem(freezing) with multiple savage colorgraphics cards (5333:8A22)
 	if $LSPCI -n | tr "a-z" "A-Z" | grep "5333:8A22" > /dev/null 2>&1 ; then
 		:
 	else
-        # Probe X. It will create either /xorg.conf.new or /root/xorg.conf.new
+        # Generate xorg.conf.new with normal X. 
 		$XSERVER -configure > /dev/null 2>&1
-        retval=$?
-        if [[ "$retval" != 0 ]]; then
-			echo "`date +"%b %d %T"` $ProgramName: X -configure failed." >> $logfile
-        fi
+        #retval=$?
+        #if [[ "$retval" != "0" ]]; then
+		#	echo "`date +"%b %d %T"` $ProgramName: X -configure failed." >> $logfile
+        #fi
 
 		if [[ ! -f /root/$XORG_CONF_NEW ]]; then
 			if [[ -f /$XORG_CONF_NEW ]]; then
 				cp -f /$XORG_CONF_NEW /root/
 			else
-				echo "`date +"%b %d %T"` $ProgramName: /root/$XORG_CONF_NEW is not available." >> $logfile
+                # Generate xorg.conf.new with Multi-X. 
+                /opt/MX11R7/bin/Xorg -configure -logfile /var/log/1box-server.log
+
+                if [[ ! -e /root/$XORG_CONF_NEW ]]; then
+			        if [[ -f /$XORG_CONF_NEW ]]; then
+				        cp -f /$XORG_CONF_NEW /root/
+                    else
+                        echo "`date +"%b %d %T"` $ProgramName: /root/$XORG_CONF_NEW is not available." >> $logfile
+                    fi
+                fi
 			fi
 		fi
 	fi
 
-	# create userful.xorg.conf.all and userful.xorg.conf.one for configuration screen
+	# create userful.xorg.conf.all and userful.xorg.conf.one
 	/opt/userful/bin/dm-gen-xconfig.sh -one
 	/opt/userful/bin/dm-gen-xconfig.sh -all
 	#if [[ -f /root/$XORG_CONF_NEW ]]; then
@@ -244,35 +254,50 @@ function configure_mx()
 	
 	# check reseller's logo
 	rm -f /opt/userful/images/reseller-logo.jpg
-	/opt/userful/bin/sno-comp
+
+    if [ -x /opt/userful/bin/dm-gen-info ]; then
+        /opt/userful/bin/dm-gen-info -licenseinfo -compare
+    else
+	    /opt/userful/bin/sno-comp
+    fi
+
 	source /etc/userful/userful-license-info
 	if [ "$RESELLER_LOGO" != "" -a -e /opt/userful/images/reseller/$RESELLER_LOGO.jpg ]; then
 		echo "`date +"%b %d %T"` $ProgramName: Use reseller log: $RESELLER_LOGO.jpg" >>  $logfile
 		cp -f /opt/userful/images/reseller/$RESELLER_LOGO.jpg /opt/userful/images/reseller-logo.jpg
 	fi
 
-	# Set the X_CONFIG_FILE to userful.xorg.conf.one for some distros that use Xorg 6.9/7.0.
-	# New X (Xorg 6.9/7.0) has problem with multiple graphic cards.
+    # TODO:
+    #  - There must be a better way to set the version of Multi-X
+
 	source /etc/userful/os-info
 	# use new Multi-X for FC6
     if [ -f /opt/MX11R7/bin/Xorg ]; then
-	    if [ "$OSNAME" == "fedora" -a "$OSVER" == "6" -o \
-		    "$OSNAME" == "fedora" -a "$OSVER" == "7" -o \
-		    "$OSNAME" == "suse" -a "$OSVER" == "10.1" -o \
-		    "$OSNAME" == "suse" -a "$OSVER" == "10.2" -o \
-		    "$OSNAME" == "novell" -a "$OSVER" == "10" -o \
-		    "$OSNAME" == "ubuntu" -a "$OSVER" == "6.06" -o \
-		    "$OSNAME" == "ubuntu" -a "$OSVER" == "6.10" -o \
-		    "$OSNAME" == "ubuntu" -a "$OSVER" == "7.04" -o \
-		    "$OSNAME" == "ubuntu" -a "$OSVER" == "7.10" ]; then
-		    echo "MXVER=MX11R7" > /etc/userful/MXVERSION
-	    else
+	    if [ "$OSNAME" == "fedora" -a "$OSVER" == "2" -o \
+		    "$OSNAME" == "fedora" -a "$OSVER" == "3" -o \
+		    "$OSNAME" == "fedora" -a "$OSVER" == "4" -o \
+		    "$OSNAME" == "novell" -a "$OSVER" == "9" -o \
+		    "$OSNAME" == "suse" -a "$OSVER" == "9.1" -o \
+		    "$OSNAME" == "suse" -a "$OSVER" == "9.3" -o \
+		    "$OSNAME" == "centos" -a "$OSVER" == "4" -o \
+		    "$OSNAME" == "freedows" -a "$OSVER" == "2005" -o \
+		    "$OSNAME" == "ubuntu" -a "$OSVER" == "5.04" -o \
+		    "$OSNAME" == "ubuntu" -a "$OSVER" == "5.10" -o \
+		    "$OSNAME" == "xandros" -a "$OSVER" == "3.0" -o \
+		    "$OSNAME" == "xandros" -a "$OSVER" == "4.0" -o \
+		    "$OSNAME" == "morphix" -a "$OSVER" == "0.5-pre5" -o \
+		    "$OSNAME" == "freespire" -a "$OSVER" == "1.0.4" -o \
+		    "$OSNAME" == "debian" -a "$OSVER" == "3.1" ]; then
 		    echo "MXVER=MX11R6" > /etc/userful/MXVERSION
+	    else
+		    echo "MXVER=MX11R7" > /etc/userful/MXVERSION
 	    fi
     else
 		echo "MXVER=MX11R6" > /etc/userful/MXVERSION
     fi
 
+	# Set the X_CONFIG_FILE to userful.xorg.conf.one for some distros that use Xorg 6.9/7.0.
+	# New X (Xorg 6.9/7.0) has problem with multiple graphic cards.
 	if [ -n "$OSNAME" -a -n "$OSVER" ]; then
 		if [ "$OSNAME" == "novell" -a "$OSVER" == "10" ] || 
 			[ "$OSNAME" == "ubuntu" -a "$OSVER" == "6.06" ]; then # Novell 10, Ubuntu 6.06
@@ -288,58 +313,59 @@ function configure_mx()
 
 	# check if config-message program starts properly.
 	# Multiple Colorgraphics savage cards causes normal X hung.
-	/opt/userful/bin/watch-x-config.sh &
+	#/opt/userful/bin/watch-x-config.sh &
 
 	if [ -n "$CARDNAME" -a -n "$CPUTYPE" ]; then # In case of Laptop 
 		if [ $NUM_OF_TOUCH -gt 0 ]; then
 			if [ "$IS_NVIDIA_DRIVER" == "false" ]; then
 				xinit /opt/userful/bin/config-message $1 -cpu "$CPUTYPE" -vga "$CARDNAME" -nonvidia \
-					-touchscreen $NUM_OF_TOUCH -- $XSERVER -xf86config $X_CONFIG_FILE
+					-touchscreen $NUM_OF_TOUCH -- $XSERVER -config $X_CONFIG_FILE
 			else
 				xinit /opt/userful/bin/config-message $1 -cpu "$CPUTYPE" -vga "$CARDNAME" \
-					-touchscreen $NUM_OF_TOUCH -- $XSERVER -xf86config $X_CONFIG_FILE
+					-touchscreen $NUM_OF_TOUCH -- $XSERVER -config $X_CONFIG_FILE
 			fi
 		else
 			if [ "$IS_NVIDIA_DRIVER" == "false" ]; then
 				xinit /opt/userful/bin/config-message $1 -cpu "$CPUTYPE" -vga "$CARDNAME" -nonvidia \
-					-- $XSERVER -xf86config $X_CONFIG_FILE
+					-- $XSERVER -config $X_CONFIG_FILE
 			else
 				xinit /opt/userful/bin/config-message $1 -cpu "$CPUTYPE" -vga "$CARDNAME" \
-					-- $XSERVER -xf86config $X_CONFIG_FILE
+					-- $XSERVER -config $X_CONFIG_FILE
 			fi
 		fi
 	elif [ $NUM_OF_TOUCH -gt 0 ]; then # Normal Desktop with touchscreen
 		if [ "$IS_NVIDIA_DRIVER" == "false" ]; then
 			xinit /opt/userful/bin/config-message $1 -touchscreen $NUM_OF_TOUCH -nonvidia \
-				-- $XSERVER -xf86config $X_CONFIG_FILE
+				-- $XSERVER -config $X_CONFIG_FILE
 		else
 			xinit /opt/userful/bin/config-message $1 -touchscreen $NUM_OF_TOUCH \
-				-- $XSERVER -xf86config $X_CONFIG_FILE
+				-- $XSERVER -config $X_CONFIG_FILE
 		fi
 	else # Normal desktop 
 		check_dualview
 		if [ "$IS_NVIDIA_DRIVER" == "false" ]; then
 			xinit /opt/userful/bin/config-message $1 -dualview $DUALVIEW -nonvidia \
-				-- $XSERVER -xf86config $X_CONFIG_FILE
+				-- $XSERVER -config $X_CONFIG_FILE
 		else
 			xinit /opt/userful/bin/config-message $1 -dualview $DUALVIEW \
-				-- $XSERVER -xf86config $X_CONFIG_FILE
+				-- $XSERVER -config $X_CONFIG_FILE
 		fi
 	fi
 
 	RET=`cat /tmp/ret-config-message`
-	if [ $RET -eq 1 ]; then
+	if [ "$RET" == "1" ]; then
 		# use old config file
 		echo "`date +"%b %d %T"` $ProgramName: Use old configuration instead of creating new one." >>  $logfile
 		$LSPCI -n | grep "0300: " > /etc/X11/vgainfo
 		return 0
-	elif [ $RET -ne 0 ]; then
+    fi
+	#elif [ $RET -ne 0 ]; then
 		# exit from startup procedure
-		echo "`date +"%b %d %T"` $ProgramName: Failed to configure system." >>  $logfile
-		pkill prefdm_multi
-		chvt 2
-		exit 1
-	fi
+		#echo "`date +"%b %d %T"` $ProgramName: Failed to configure system." >>  $logfile
+		#pkill prefdm_multi
+		#chvt 2
+		#exit 1
+	#fi
 
 	###
 	# create userful.Mxorg.conf
@@ -351,7 +377,11 @@ function configure_mx()
 	rm -f /etc/X11/xdm/Xservers
 	rm -f /etc/mvgainfo
 
-	/opt/userful/bin/sno-comp
+    if [ -x /opt/userful/bin/dm-gen-info ]; then
+        /opt/userful/bin/dm-gen-info -licenseinfo -compare
+    else
+	    /opt/userful/bin/sno-comp
+    fi
 	$LSPCI -n | grep "0300: " > /etc/X11/vgainfo
 
 	# create config files
@@ -440,12 +470,20 @@ else
 		configure_mx -r
 	fi
 	
-	/opt/userful/bin/sno-comp
+    if [ -x /opt/userful/bin/dm-gen-info ]; then
+        /opt/userful/bin/dm-gen-info -compare
+    else
+	    /opt/userful/bin/sno-comp
+    fi
 	if [ $? != 0 ]; then
 		# there is change in the # of station of the key file
 		# no need to re-create config file
 		rm -f /etc/X11/xdm/Xservers
 		rm -f /etc/stations
-		/opt/userful/bin/sno-comp
+        if [ -x /opt/userful/bin/dm-gen-info ]; then
+            /opt/userful/bin/dm-gen-info -compare
+        else
+	        /opt/userful/bin/sno-comp
+        fi
 	fi
 fi
