@@ -19,3 +19,14 @@ loadkeys /opt/userful/bin/userful.keymap 2>> $logfile
 # Disable VT change
 echo "`date +"%b %d %T"` $ProgramName: Disable VT change" >>  $logfile
 /opt/userful/bin/vtlock -enable
+
+# Add read permission for config files
+if [[ -e /etc/usbinput ]]; then
+    chmod 644 /etc/usbinput
+fi
+if [[ -e /etc/usbaudio ]]; then
+    chmod 644 /etc/usbaudio
+fi
+if [[ -e /etc/multiuserdevices ]]; then
+    chmod 644 /etc/multiuserdevices
+fi
