@@ -44,6 +44,11 @@ rm -f /tmp/unplug.tmp
 rm -f /tmp/plug-inputdev
 rm -f /tmp/touchscreen-dev
 
+# Create dm directory under /var/log
+if [[ ! -d /var/log/dm ]]; then
+    mkdir /var/log/dm
+fi
+
 # Check if MX is running already
 if [ -e /var/run/x.pid ]; then
 	if [ -e /proc/`cat /var/run/x.pid` ]; then
@@ -229,7 +234,6 @@ else
        	CURRENTDM=xdm
 		echo "DISPLAYMANAGER=XDM" > /etc/sysconfig/desktop 
 	fi
-
 fi
 
 # check if Display Manager has been changed from last time
@@ -257,13 +261,6 @@ if [ -e /etc/X11/xorg.conf ]; then
 	fi
 fi
 
-#
-# use gksu instead of dm-runasroot if it exists
-#
-if which gksu > /dev/null 2>&1; then
-	sed -i -e "s/^Exec=.*/Exec=gksu \/usr\/share\/1box-utils\/about-dialog.py/g" /usr/share/applications/userful-about-dialog.desktop
-fi
-
 #
 # Disable SELINUX
 #
@@ -283,4 +280,29 @@ fi
 ## Sun driver causes problem for "X -configure" operation in SuSE10.2
 if [[ -d /usr/lib/xorg/modules/drivers ]]; then
     rm -f /usr/lib/xorg/modules/drivers/sun*
+elif [[ -d /usr/lib64/xorg/modules/drivers ]]; then
+    rm -f /usr/lib64/xorg/modules/drivers/sun*
 fi
+
+##
+## Create a softlink for libwfb.so if it exists.
+if [[ -e /usr/lib/xorg/modules/extensions/nvidia/libwfb.so ]] && [[ ! -e /usr/lib/xorg/modules/extensions/libwfb.so ]]; then
+    ln -sf /usr/lib/xorg/modules/extensions/nvidia/libwfb.so /usr/lib/xorg/modules/extensions/libwfb.so
+elif [[ -e /usr/lib64/xorg/modules/extensions/nvidia/libwfb.so ]] && [[ ! -e /usr/lib64/xorg/modules/extensions/libwfb.so ]]; then
+    ln -sf /usr/lib64/xorg/modules/extensions/nvidia/libwfb.so /usr/lib64/xorg/modules/extensions/libwfb.so
+fi
+
+##
+## Create sys-id 
+if [[ -x /opt/userful/bin/dm-gen-info ]]; then
+    /opt/userful/bin/dm-gen-info -sysid
+fi
+
+##
+## Make sure that the hotplug rule exist under /etc/udev/rules.d/ 
+if [[ -d /etc/udev/rules.d ]]; then
+    if [[ ! -f /etc/udev/rules.d/99-userful-hotplug.rules ]]; then
+        cp -f /etc/userful/setup/99-userful-hotplug.rules /etc/udev/rules.d/
+    fi
+fi
+
