@@ -58,6 +58,18 @@ update_mx_config()
 # Start Multi X
 start_mx()
 {
+    # Message
+    clear
+    echo
+    #echo -e "Starting \E[36m\033[1mUSERFUL\033[0m \033[1mDesktop Multiplier\033[0m. Please wait..."
+    echo -e "Starting \E[36mUSERFUL\033[0m Desktop Multiplier. Please wait..."
+
+    # Waiting for usbhub and input device initialization.
+    if [[ -x /opt/userful/bin/waiting-for.sh ]]; then
+        /opt/userful/bin/waiting-for.sh --hub -interval 3
+        /opt/userful/bin/waiting-for.sh --input -interval 2
+    fi
+
 	source /etc/userful/MXVERSION
 
 	# load nvidia module if nvidia driver exist
@@ -75,13 +87,14 @@ start_mx()
 
 	# create usbinput config file
 	echo "`date +"%b %d %T"` $ProgramName: Create /etc/usbinput and symbolic link in /etc/X11/Xinput/ directory" >>  $logfile
-	/opt/userful/bin/make-config-file
+	/opt/userful/bin/make-config-file 2>> $logfile
 
 	# update userful.Mxorg.conf before X starts
 	update_mx_config
 
     if [ -f /etc/userful/dm.conf ]; then
-        source /etc/userful/dm.conf
+        sed -e "s/^\[/#\[/g" /etc/userful/dm.conf > /tmp/dm.conf.tmp
+        source /tmp/dm.conf.tmp
     fi
 
 	if which date > /dev/null 2>&1; then
@@ -108,10 +121,10 @@ start_mx()
     if [ "$DMTYPE" == "remote" ]; then
         # Need to listen TCP connection, add -ac option to disable access control restriction
         xinit /opt/userful/bin/mx.xinitrc  -- /opt/$MXVER/bin/X :0 $IGNOREABI \
-		    -ac -br -logfile /var/log/1box-server.log -xf86config userful.Mxorg.conf &	
+		    -ac -br -logfile /var/log/1box-server.log -config userful.Mxorg.conf &	
     else
         xinit /opt/userful/bin/mx.xinitrc  -- /opt/$MXVER/bin/X :0 $IGNOREABI \
-		    -br -logfile /var/log/1box-server.log -nolisten tcp -xf86config userful.Mxorg.conf &	
+		    -br -logfile /var/log/1box-server.log -nolisten tcp -config userful.Mxorg.conf &	
     fi
 
 	sleep 1
@@ -254,6 +267,16 @@ start_1box_server()
 		echo "`date +"%b %d %T"` $ProgramName: Multi-X started." >>  $logfile
 		# start MX successfully
 		echo 0 > /etc/userful/start-mx
+
+        # Update the current numbers of station, keyboard and mouse
+	    /opt/userful/bin/make-config-file -u
+
+        # Disable DPMS explicitly.  DPMS hasn't been virtualized yet..
+        # Radeon driver seems to have some problems with DPMS.
+        if which xset > /dev/null 2>&1; then
+            echo "`date +"%b %d %T"` $ProgramName: xset -display :0 -dpms" >>  $logfile
+            xset -display :0 -dpms
+        fi
 	fi
 }
 
