@@ -37,16 +37,6 @@ case "$OSNAME" in
 		SUPPORTED_VER=$SUSE
 		;;
 
-	jds)
-		SUPPORTED_VER=$JDS
-		SUPPORTED_OS=$TRUE
-		;;
-		
-	redhat)
-		SUPPORTED_VER=$REDHAT
-		SUPPORTED_OS=$TRUE
-		;;
-
 	centos)
 		SUPPORTED_VER=$CENTOS
 		;;
@@ -71,31 +61,25 @@ case "$OSNAME" in
 		SUPPORTED_VER=$FREESPIRE
 		;;
 
-	linspire)
-		SUPPORTED_VER=$LINSPIRE
-		SUPPORTED_OS=$TRUE
-		;;
-
 	debian)
 		SUPPORTED_VER=$DEBIAN
 		;;
 
-	mepis)
-		SUPPORTED_VER=$MEPIS
-		SUPPORTED_OS=$TRUE
-		;;
-
 	*)
 		SUPPORTED_OS=$FALSE
 		;;
 esac
 
-for V in $SUPPORTED_VER; do
-	if [ "$V" == "$OSVER" ]; then
-		SUPPORTED_OS=$TRUE
-		break
-	fi
-done
+if [ "$SUPPORTED_VER" == "none" -o "$SUPPORTED_VER" == "" ]; then
+    SUPPORTED_OS=$FALSE
+else
+    for V in $SUPPORTED_VER; do
+	    if [ "$V" == "$OSVER" ]; then
+		    SUPPORTED_OS=$TRUE
+		    break
+	    fi
+    done
+fi
 
 if [ $SUPPORTED_OS -eq $TRUE ]; then
 	exit 0  # supported
