@@ -151,12 +151,30 @@ function parse_xorg_conf_new()
 
     if [[ "$xconfigtype" == "-1box" ]]; then
         SECTION_STRING="Section \"Files\""
-        if [[ "$MXVER" == "MX11R6" ]]; then
-            MODULEPATH="ModulePath\t\"\/opt\/MX11R6\/$LIB\/modules\""
+
+        if grep -m 1 "MX11R7" $FILES_SECTION_FILE > /dev/null 2>&1; then
+            # xorg.conf.new was create by "/opt/MX11R7/bin/Xorg -configure", need to add *builtin* module path.
+            MODULEPATH="ModulePath\t\"\/opt\/MX11R7\/lib\/xorg\/modules\"\n\tModulePath\t\"\/usr\/$LIB\/xorg\/modules\""
+            sed -i -e "/ModulePath/d" $FILES_SECTION_FILE
         else
-            MODULEPATH="ModulePath\t\"\/opt\/MX11R7\/lib\/xorg\/modules\""
+            # xorg.conf.new was create by "X -configure", need to add *MultiX* module path.
+            if [[ "$MXVER" == "MX11R6" ]]; then
+                MODULEPATH="ModulePath\t\"\/opt\/MX11R6\/$LIB\/modules\""
+            else
+                MODULEPATH="ModulePath\t\"\/opt\/MX11R7\/lib\/xorg\/modules\""
+            fi
         fi
         sed -i -e "s/$SECTION_STRING/$SECTION_STRING\n\t$MODULEPATH/" $FILES_SECTION_FILE
+    else
+        # -one -all -check, These options create the configuration file for normal X server
+        SECTION_STRING="Section \"Files\""
+
+        if grep -m 1 "MX11R7" $FILES_SECTION_FILE > /dev/null 2>&1; then
+            # xorg.conf.new was create by "/opt/MX11R7/bin/Xorg -configure", need to add builtin module path
+            MODULEPATH="ModulePath\t\"\/usr\/$LIB\/xorg\/modules\"\n\tModulePath\t\"\/opt\/MX11R7\/lib\/xorg\/modules\""
+            sed -i -e "/ModulePath/d" $FILES_SECTION_FILE
+            sed -i -e "s/$SECTION_STRING/$SECTION_STRING\n\t$MODULEPATH/" $FILES_SECTION_FILE
+        fi
     fi
 
     #################
@@ -1507,6 +1525,9 @@ function genDeviceSection()
 
 		elif [[ "$xconfigtype" == "-check" ]] ;then
 
+
+            VENDOR_ID=`echo $DEVID | awk -F':' '{print $1}'`
+
 			if [[ "$DRIVER" == "" ]]; then
 				echo "`date +"%b %d %T"` $ProgramName: Couldn't find VGA driver for device $BOARDNAME" >> $logfile
 				HEADNO=1
@@ -1532,6 +1553,14 @@ function genDeviceSection()
 				HEADNO=1
 				echo "$BUSID^$VENDORNAME^$BOARDNAME^$DRIVER^$HEADNO^$DEVID" >> /etc/mvgainfo
 
+            # TODO:
+            #   Need better way to check dual-head card
+            #   Consider every intel card as one head for now.
+            elif [[ "$VENDOR_ID" == "8086" ]]; then
+				echo "`date +"%b %d %T"` $ProgramName: Found Intel graphics card. Use it as a single head card by default." >> $logfile
+				HEADNO=1
+				echo "$BUSID^$VENDORNAME^$BOARDNAME^$DRIVER^$HEADNO^$DEVID" >> /etc/mvgainfo
+               
 			else
 				#touch flag file
 				touch /etc/userful/dm-config-processing
