@@ -14,7 +14,7 @@ UNLINK=0
 DISPLAYNUM=
 SCREENNUM=
 CURRENTDM=
-LOCK_FILE=/tmp/unlik-kbd.lock
+LOCK_FILE=/tmp/unlink-kbd.lock
 
 ##########
 # usage()
@@ -30,13 +30,40 @@ function usage()
 #-------------------
 # Start here...
 #-------------------
-
-[[ -f /etc/userful/dm.conf ]] && source /etc/userful/dm.conf
+# 
+if [[ -f /etc/userful/dm.conf ]]; then
+    sed -e "s/^\[/#\[/g" /etc/userful/dm.conf > /tmp/dm.conf.tmp
+    source /tmp/dm.conf.tmp
+fi 
 if [ "$CTRLALTBREAK" == "disable" ]; then
 	echo "`date +"%b %d %T"` $ProgramName: Ctrl-Alt-Break is disabled." >> $logfile
 	exit 0
 fi
 
+# This is bug fix for locale problem in Educational Linux
+if [[ -f /etc/default/locale ]]; then
+    echo "`date +"%b %d %T"` [$ProgramName]: source locale" >> $logfile
+    source /etc/default/locale 2>> $logfile
+    while read line; do
+        VARS_NAME=`echo $line | awk -F'=' '{print $1}'`
+        export $VARS_NAME >> $logfile
+    done < /etc/default/locale
+
+    if [[ -f /etc/bash.bashrc ]]; then
+        source /etc/bash.bashrc
+    fi
+    if [[ -f /etc/profile ]]; then
+        source /etc/profile
+    fi
+
+    if [[ -f /root/.bashrc ]]; then
+        source /root/.bashrc
+    fi
+    if [[ -f /root/.profile ]]; then
+        source /root/.profile
+    fi
+fi
+
 # receive only one argument(screenNum).  
 [[ $# -ne 1 ]] && usage
 SCREENNUM=$1
@@ -61,6 +88,7 @@ if [[ -e $LOCK_FILE ]]; then
 	exit 1
 fi
 : > $LOCK_FILE
+rm -f /etc/usbinput.tmp
 
 # We need to set environment variables for language translation. ($LANG)
 # This could be different for each distro.
@@ -153,4 +181,5 @@ fi
 #echo "unlink-kbd.sh  send signal HUP to GUI " >> $logfile
 /usr/bin/killall -s HUP userful-usbinput-config
 
+rm -f /etc/usbinput.tmp
 rm -f  $LOCK_FILE
