@@ -129,7 +129,10 @@ echo "`date +"%b %d %T"` $ProgramName:  $PHYS removed." >> $usbinput_logfile
 echo "`date +"%b %d %T"` $ProgramName:  $PHYS removed." >> $logfile
 
 # Check the device config type.  If it is static, then exit program.
-source /etc/userful/dm.conf
+if [[ -f /etc/userful/dm.conf ]]; then
+    sed -e "s/^\[/#\[/g" /etc/userful/dm.conf > /tmp/dm.conf.tmp
+    source /tmp/dm.conf.tmp
+fi
 if [ "$DEVCONF" == "static" ]; then
     echo "`date +"%b %d %T"` $ProgramName: Current device config type is static. Do nothing." >> $logfile
     exit 0
