@@ -27,6 +27,20 @@ SCREENNUM=
 TRUE=1
 FALSE=0
 
+# Exit from this hotplug agent program if:
+#  - X is not running.
+#  - During X startup
+if [[ ! -e /var/run/x.pid ]]; then
+    exit 1
+elif ! kill -0 `cat /var/run/x.pid` > /dev/null 2>&1; then
+    exit 1
+fi
+
+# During the X start, don't run userful hotplug agent too.
+if [[ -e /tmp/X-start ]]; then
+    exit 1
+fi
+
 # start GUI for kbd-assignment. unconfigure devices that have same screenNum.
 function unplug_kbd()
 {
@@ -70,6 +84,30 @@ function unplug_kbd()
 		CURRENTDM=gdm
 	fi
 
+    # This is bug fix for locale problem in Educational Linux
+    if [[ -f /etc/default/locale ]]; then
+        echo "`date +"%b %d %T"` [$ProgramName]: source locale" >> $logfile
+        source /etc/default/locale 2>> $logfile
+        while read line; do
+            VARS_NAME=`echo $line | awk -F'=' '{print $1}'`
+            export $VARS_NAME >> $logfile
+        done < /etc/default/locale
+
+        if [[ -f /etc/bash.bashrc ]]; then
+            source /etc/bash.bashrc
+        fi
+        if [[ -f /etc/profile ]]; then
+            source /etc/profile
+        fi
+
+        if [[ -f /root/.bashrc ]]; then
+            source /root/.bashrc
+        fi
+        if [[ -f /root/.profile ]]; then
+            source /root/.profile
+        fi
+    fi
+
 	# check if GUI for kbd-assignment exists on the $SCREENNUM display
 	if [ ! -e /var/run/pid.kbdlink$((10#$SCREENNUM)) -o \
 		 ! -d /proc/`cat /var/run/pid.kbdlink$((10#$SCREENNUM))` ]; then
@@ -129,11 +167,17 @@ if [ $# -ne 1 ]; then
     usage
 fi
 
+# Touch input-hotplug file
+touch /tmp/input-hotplug
+
 echo "`date +"%b %d %T"` $ProgramName:  $1 removed." >> $usbinput_logfile
 echo "`date +"%b %d %T"` $ProgramName:  $1 removed." >> $logfile
 
 # Check the device config type.  If it is static, then exit program.
-source /etc/userful/dm.conf
+if [[ -e /etc/userful/dm.conf ]]; then
+    sed -e "s/^\[/#\[/g" /etc/userful/dm.conf > /tmp/dm.conf.tmp
+    source /tmp/dm.conf.tmp
+fi
 if [ "$DEVCONF" == "static" ]; then
     echo "`date +"%b %d %T"` $ProgramName: Current device config type is static. Do nothing." >> $logfile
     exit 0
