@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (c) 2002-2006 Userful Corporation. All rights reserved.
+# Copyright (c) 2002-2007 Userful Corporation. All rights reserved.
 # http://userful.com/
 
 # about-dialog.py
@@ -17,6 +17,11 @@ try:
 except:
     use_sp = False
 
+import gettext
+gettext.bindtextdomain('userful-about-dialog')
+gettext.textdomain('userful-about-dialog')
+_ = gettext.gettext
+
 class PyGlade:
     glade_filename = 'about-dialog.glade'
     paths = []
