@@ -26,8 +26,6 @@ URL="http://store.userful.com/license/control/licenseRegister?"
 # for testing
 #URL="http://bob.userful.ca/license/control/freelicense?"
 
-FIRST_ARG=true
-
 ETH_NUM=0
 
 MAC=`LANG=C /sbin/ifconfig -a eth$ETH_NUM | grep "HWaddr" | awk '{ print $5 }'`
@@ -37,8 +35,14 @@ if [ -z "$MAC" ] || [ ${#MAC} != 17 ] ; then
     MAC=nomac
 fi
 
+SYSID=none
+if [ -f /etc/userful/sys-id ] ; then
+    SYSID=`cat /etc/userful/sys-id`
+fi
+URL="${URL}sysid=$SYSID"
+
 # license file order:
-# http://sugar.userful.ca:8080/wiki/index.php?title=License_File
+# http://wiki.userful.ca/wiki/index.php?title=License_File
 # : - _
 
 MAC_COLONS=$MAC
@@ -63,23 +67,19 @@ LICENSE_KEY=
 if [ -n "$FILENAME" ] ; then
     echo Found license: $FILENAME
     LICENSE_KEY="`/usr/share/1box-utils/b64encode.py $FILENAME`"
-    if [ $FIRST_ARG != true ] ; then
-        URL="${URL}&"
-    fi
-    FIRST_ARG=false
-    URL="${URL}lickey=$LICENSE_KEY"
+    URL="${URL}&lickey=$LICENSE_KEY"
 fi
 #fi # if false
 
+if [ $SYSID != none ] ; then
+    MAC=000000000000
+    # why not? 00000000
+fi
 
 if [ $MAC == nomac ] ; then
     exec $ERR_DLG "No valid MAC address found. Please contact Userful: http://store.userful.com/ or 1-(866)-USERFUL."
 else
-    if [ $FIRST_ARG != true ] ; then
-        URL="${URL}&"
-    fi
-    FIRST_ARG=false
-    URL="${URL}mac=${MAC//:/}"
+    URL="${URL}&mac=${MAC//:/}"
 fi
 
 if false ; then
@@ -91,11 +91,7 @@ if [ -r /dev/mem ] ; then
         gzip /tmp/hardware-$$
         HARDWARE="`/usr/share/1box-utils/b64encode.py /tmp/hardware-$$.gz`"
         if [ -n "$HARDWARE" ] ; then
-            if [ $FIRST_ARG != true ] ; then
-                URL="${URL}&"
-            fi
-            FIRST_ARG=false
-            URL="${URL}info=$HARDWARE"
+            URL="${URL}&info=$HARDWARE"
         fi
     fi
 fi
