@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Copyright (c) 2002-2006 Userful Corporation. All rights reserved.
+# Copyright (c) 2002-2007 Userful Corporation. All rights reserved.
 # http://userful.com/
 
 # comment this out for distribution
@@ -293,13 +293,27 @@ fi
 #########################
 mkdir $DEST/proc
 
-#- /proc/bus/input/devices
 if [ -r /proc/bus/input/devices ] ; then
     cat /proc/bus/input/devices > $DEST/proc/input-devices
 else
     echo "{EE} Could not read" > $DEST/proc/input-devices
 fi
 
+if [ -r /proc/cpuinfo ]; then
+    cat /proc/cpuinfo > $DEST/proc/cpuinfo
+fi
+
+if [ -r /proc/version ]; then
+    cat /proc/version > $DEST/proc/version
+fi
+
+if [ -r /proc/asound/cards ]; then
+    cat /proc/asound/cards > $DEST/proc/asound-cards
+fi
+if [ -r /proc/asound/version ]; then
+    cat /proc/asound/version > $DEST/proc/asound-version
+fi
+
 #- /proc/bus/usb/devices
 #if [ -r /proc/bus/usb/devices ] ; then
 #    cat /proc/bus/usb/devices > $DEST/proc/usb-devices
